Model
=================================
Model
---------------------------------
.. automodule:: deoxys.model.model
   :members:
   :undoc-members:

Layers
---------------------------------
.. automodule:: deoxys.model.layers
   :members:
   :undoc-members:

Activations
---------------------------------
.. automodule:: deoxys.model.activations
   :members:
   :undoc-members:

Losses
---------------------------------
.. automodule:: deoxys.model.losses
   :members:
   :undoc-members:

Metrics
---------------------------------
.. automodule:: deoxys.model.metrics
   :members:
   :undoc-members:

Optimizers
---------------------------------
.. automodule:: deoxys.model.optimizers
   :members:
   :undoc-members:

Callbacks
---------------------------------
.. automodule:: deoxys.model.callbacks
   :members:
   :undoc-members:
